@@ -1,5 +1,5 @@
 use crate::document::{Document, DocumentState, ActionHistory};
-use crate::editorgui::{Packages, ResourceType, EditorConfig, ProjectConfig};
+use crate::editorgui::{Packages, EditorConfig, ProjectConfig};
 
 use std::any::Any;
 
@@ -72,7 +72,8 @@ impl SpawnableSetDocument
         false
     }
 
-    fn spawnable_tab(&mut self, packages : &mut Packages, ui : &imgui::Ui, spawnables : &SpawnableSet, spawnable : &Spawnable)
+    fn spawnable_tab(&mut self, packages : &mut Packages, ui : &imgui::Ui,
+                     spawnables : &SpawnableSet, spawnable : &Spawnable, sheet_store : &DataStore<Sheet>)
     {
         ui.text(format!("Editing Spawnable {}", self.current_spawnable));
         ui.spacing();
@@ -104,59 +105,67 @@ impl SpawnableSetDocument
             self.queue_action(Box::new(SpawnableSetAction::SetSpawnable(self.current_spawnable, spawnable_clone)));
         }
 
-        imgui::ChildWindow::new("representation_controls").size([0.0, 90.0]).draw_background(false).border(false).build(ui, ||
+        imgui::ChildWindow::new("representation_controls").size([0.0, 116.0]).draw_background(false).border(false).build(ui, ||
         {
             ui.indent_by(10.0);
 
             match spawnable.representation()
             {
                 Representation::None => {}
+                Representation::Prop { sheet, slice } =>
+                {
+                    let mut update_prop = false;
+                    let mut package_name = sheet.package().clone();
+                    let mut sheet_name = sheet.path().clone();
+                    let mut slice_name = slice.clone();
+
+                    ui.spacing();
+
+                    if let Some((package, sheet, slice)) = crate::util::widget::sheet_slice_popup(packages, ui, &sheet_store)
+                    {
+                        update_prop = true;
+                        package_name = package;
+                        sheet_name = sheet;
+                        slice_name = slice;
+                    }
+
+                    let style_var = ui.push_style_var(imgui::StyleVar::ItemSpacing([-1.0, -1.0]));
+                    let width = ui.push_item_width(ui.column_width(0) * 0.6);
+
+                    update_prop |= ui.input_text("Sheet Package", &mut package_name).enter_returns_true(true).build();
+                    update_prop |= ui.input_text("Sheet Name", &mut sheet_name).enter_returns_true(true).build();
+                    update_prop |= ui.input_text("Slice Name", &mut slice_name).enter_returns_true(true).build();
+
+                    width.pop(ui);
+                    style_var.pop();
+
+                    if update_prop
+                    {
+                        let mut spawnable_clone = spawnable.clone();
+
+                        spawnable_clone.set_representation(Representation::Prop
+                        {
+                            sheet : DataHandle::with_path(&package_name, &sheet_name),
+                            slice : slice_name
+                        });
+
+                        self.queue_action(Box::new(SpawnableSetAction::SetSpawnable(self.current_spawnable, spawnable_clone)));
+                    }
+                }
                 Representation::Actor { costume } =>
                 {
                     let mut update_actor = false;
                     let mut package_name = costume.package().clone();
                     let mut costume_name = costume.path().clone();
 
-                    ui.popup("Pick Costume Menu", ||
-                    {
-                        let mut package_to_load: Option<String> = None;
-
-                        for package in packages.package_iter()
-                        {
-                            ui.menu(package, ||
-                            {
-                                if !packages.package_loaded(ResourceType::Costume, package)
-                                {
-                                    package_to_load = Some(package.clone());
-                                }
-
-                                for costume in packages.package_contents(ResourceType::Costume, package)
-                                {
-                                    if imgui::Selectable::new(costume).build(ui)
-                                    {
-                                        package_name.clear();
-                                        package_name.push_str(package);
-                                        costume_name.clear();
-                                        costume_name.push_str(costume);
-
-                                        update_actor = true;
-                                    }
-                                }
-                            });
-                        }
-
-                        if let Some(package) = package_to_load
-                        {
-                            packages.load_package_later(ResourceType::Costume, &package);
-                        }
-                    });
-
                     ui.spacing();
-                    if ui.button("Pick Costume")
+
+                    if let Some((package, costume)) = crate::util::widget::costume_popup(packages, ui)
                     {
-                        ui.open_popup("Pick Costume Menu");
+                        update_actor = true;
+                        package_name = package;
+                        costume_name = costume;
                     }
-                    ui.spacing();
 
                     let style_var = ui.push_style_var(imgui::StyleVar::ItemSpacing([-1.0, -1.0]));
                     let width = ui.push_item_width(ui.column_width(0) * 0.6);
@@ -173,7 +182,7 @@ impl SpawnableSetDocument
 
                         spawnable_clone.set_representation(Representation::Actor
                         {
-                            costume: DataHandle::with_path(&package_name, &costume_name)
+                            costume : DataHandle::with_path(&package_name, &costume_name)
                         });
 
                         self.queue_action(Box::new(SpawnableSetAction::SetSpawnable(self.current_spawnable, spawnable_clone)));
@@ -242,35 +251,42 @@ impl SpawnableSetDocument
     fn spawnable_image(&mut self, packages : &mut Packages, ui : &imgui::Ui, sheet_store : &mut DataStore<Sheet>, costume_store : &mut DataStore<Costume>, spawnable : &Spawnable)
     {
         let remaining = ui.content_region_avail();
+        let mut image_info = None;
 
         match spawnable.representation()
         {
             Representation::None => {}
+            Representation::Prop { sheet, slice } =>
+            {
+                image_info = crate::util::drawable::sheet_slice_image(sheet, slice, sheet_store, packages);
+            }
             Representation::Actor { costume } =>
             {
-                if let Some((mut image, rect)) = crate::util::drawable::costume_image(costume, costume_store, sheet_store, packages)
-                {
-                    let width_zoom = ((remaining[0] - 2.0) / rect.w.max(1.0)).floor();
-                    let height_zoom = ((remaining[1] - 2.0) / rect.h.max(1.0)).floor();
-                    let zoom = width_zoom.min(height_zoom).clamp(1.0, 4.0);
-                    let size = [rect.w * zoom, rect.h * zoom];
-
-                    let style_var = ui.push_style_var(imgui::StyleVar::WindowPadding([1.0, 1.0]));
-                    let style_color = ui.push_style_color(imgui::StyleColor::ChildBg, [self.transparent_color[0], self.transparent_color[1], self.transparent_color[2], 1.0]);
-
-                    imgui::ChildWindow::new("texture_view").size([size[0] + 2.0, size[1] + 2.0]).draw_background(true).border(true)
-                        .scrollable(false).movable(false).build(ui, ||
-                    {
-                        image = image.size(size);
-                        image.build(ui);
-                    });
-
-                    style_color.pop();
-                    style_var.pop();
-                }
+                image_info = crate::util::drawable::costume_image(costume, costume_store, sheet_store, packages);
             }
             Representation::Tilemap => {}
         }
+
+        if let Some((mut image, rect)) = image_info
+        {
+            let width_zoom = ((remaining[0] - 2.0) / rect.w.max(1.0)).floor();
+            let height_zoom = ((remaining[1] - 2.0) / rect.h.max(1.0)).floor();
+            let zoom = width_zoom.min(height_zoom).clamp(1.0, 4.0);
+            let size = [rect.w * zoom, rect.h * zoom];
+
+            let style_var = ui.push_style_var(imgui::StyleVar::WindowPadding([1.0, 1.0]));
+            let style_color = ui.push_style_color(imgui::StyleColor::ChildBg, [self.transparent_color[0], self.transparent_color[1], self.transparent_color[2], 1.0]);
+
+            imgui::ChildWindow::new("texture_view").size([size[0] + 2.0, size[1] + 2.0]).draw_background(true).border(true)
+                .scrollable(false).movable(false).build(ui, ||
+            {
+                image = image.size(size);
+                image.build(ui);
+            });
+
+            style_color.pop();
+            style_var.pop();
+        }
     }
 }
 
@@ -321,7 +337,7 @@ impl Document for SpawnableSetDocument
                     {
                         if let Some(tab) = imgui::TabItem::new("Spawnable").begin(ui)
                         {
-                            self.spawnable_tab(packages, ui, spawnables, spawnable);
+                            self.spawnable_tab(packages, ui, spawnables, spawnable, &sheet_store);
 
                             tab.end();
                         }
