@@ -7,7 +7,7 @@ use std::any::Any;
 use keeshond::gameloop::GameControl;
 use keeshond::renderer::Sheet;
 
-use keeshond_datapack::{DataId, DataHandle};
+use keeshond::datapack::{DataId, DataHandle};
 use keeshond_treats::tilemap::{Tileset, TilesetTile, TileCollision, TileBoundingBoxData, TileHeightmapData};
 use keeshond_treats::visual::{SliceIndexHandle};
 
@@ -675,7 +675,7 @@ impl TilesetDocument
                 }
 
                 let cursor_pos = ui.cursor_pos();
-                crate::util::tileset_image_from_slice(tileset, texture_id, sheet_opt, i, button_size).build(ui);
+                crate::util::drawable::tileset_image_from_slice(tileset, texture_id, sheet_opt, i, button_size).build(ui);
 
                 ui.set_cursor_pos([cursor_pos[0], cursor_pos[1]]);
 
@@ -988,10 +988,12 @@ impl Document for TilesetDocument
             imgui::ChildWindow::new("tileset_tile_view").size([size[0] + 2.0, size[1] + 2.0])
                 .draw_background(true).border(true).build(ui, ||
             {
+                crate::util::widget::round_cursor_screen_pos(ui);
+
                 let pos = ui.cursor_screen_pos();
                 let draw_list = ui.get_window_draw_list();
 
-                crate::util::tileset_image_from_slice(tileset, texture_id, sheet_opt, self.current_tile, size).build(ui);
+                crate::util::drawable::tileset_image_from_slice(tileset, texture_id, sheet_opt, self.current_tile, size).build(ui);
 
                 if collision_open
                 {
