@@ -1,13 +1,15 @@
 use keeshond::crate_reexport::strum::{EnumCount, IntoEnumIterator};
 use keeshond::crate_reexport::strum_macros::{Display, EnumCount, EnumIter};
 use keeshond::gameloop::GameControl;
-use keeshond::scene::{Component, ImGuiSystem, ThinkerSystem, DrawerSystem, ThinkerArgs, DrawerArgs, SceneType, NullSpawnable, SceneConfig};
+use keeshond::scene::{ImGuiSystem, ThinkerSystem, DrawerSystem, ThinkerArgs, DrawerArgs, SceneType, NullSpawnable, SceneConfig};
 use keeshond::renderer::Sheet;
 use keeshond::util::Rect;
 
 use keeshond::datapack::{DataError, DataHandle, DataStoreOk};
 use keeshond::datapack::source::{SourceId, FilesystemSource, TrustLevel};
 
+use keeshond_derive::Component;
+
 use keeshond_treats::LoadErrorMode;
 use keeshond_treats::visual::{Costume, DrawableDrawer, Drawable, ActorThinker, PixelSnap};
 use keeshond_treats::tilemap::Tileset;
@@ -630,6 +632,7 @@ fn normalize_path(mut path : String) -> String
     path
 }
 
+#[derive(Component)]
 pub struct EditorControl
 {
     pub config : EditorConfig,
@@ -985,8 +988,6 @@ impl EditorControl
     }
 }
 
-impl Component for EditorControl {}
-
 #[derive(Eq, PartialEq)]
 enum MenubarShortcut
 {
@@ -2265,7 +2266,7 @@ impl ThinkerSystem<EditorScene> for EditorThinker
         let mut comp_editor_control = args.components.store_mut::<EditorControl>();
         let (_, editor) = comp_editor_control.first_mut().unwrap();
 
-        let mut drawable_store = args.components.store_mut();
+        let mut drawable_store = args.components.store_mut::<Drawable>();
 
         if let Some((_, drawable)) = drawable_store.first_mut()
         {
